=======
taffmat
=======

Python module for reading and writing Teac TAFFmat files.

About TAFFmat
=============

TAFFmat is Teac's proprietary file format used to store data from their
LX series and other data recorders, such as the LX-10.

According to the Teac "LX Series Recording Unit Instruction Manual":

  TAFFmat (an acronym for Teac Data Acquisition File Format) is a
  file format composed of the following:

  * a data file containing A/D (analog to digital) converted data. The
  file is binary formatwith the extension dat.
  * a header file containing information such as recording
  conditions. The file is in text format with the extension hdr. 

TAFFmat is a trademark of Teac Corporation.


